import { Camera } from "./display/Camera";
import { Quad } from "./display/Quad";
import { Shader } from "./display/Shader";
import { Game, gameSetMain } from "./game/Game";
import { Scene } from "./scene/Scene";

class TestScene extends Scene {
  private quad:Quad;
  private camera:Camera;
  private shader:Shader;
  private texture:CTexture;

  init() {
    this.quad = new Quad();

    this.shader = this.game.assets.shaderLoad(
      "shaders/textured.vert", "shaders/textured.frag", this
    );
    this.texture = this.game.assets.textureLoad("test_texture.png", this);

    this.camera = new Camera();
  }

  update() {
    this.camera.perspective(45, 16/9, 0.01, 100);
    this.camera.lookAt(3,3,3, 0,0,0);

    this.shader.use();
    this.shader.setCamera(this.camera);
    this.shader.setTexture(this.texture);
    for(let i = 0; i < 3000; i++) {
      this.shader.setPosition(0,0,0, 0,this.game.time.current + (i*0.0001),0);
      this.quad.draw();
    }
  }

  dispose() {
  }
}

class MainGame extends Game {
  constructor() {
    super();
    this.setScene(new TestScene(this));
    this.scene.init();
  }
}

gameSetMain(new MainGame());